wellformednesstools.tabulate_well_formedness_violations_in_expr
===============================================================

.. autofunction:: abjad.tools.wellformednesstools.tabulate_well_formedness_violations_in_expr.tabulate_well_formedness_violations_in_expr
   :noindex:
